# modern-urwid docs

**modern-urwid** is a Python library for creating TUIs
with ``urwid`` from XML and CSS.

```{toctree}
:maxdepth: 2
:caption: Contents:

usage
api
```

```{note}
This project is under active development.
```
